@@ -45,35 +45,26 @@ sub make_singleton{
 
 sub new{
 	my ($class, @args) = @_;
-        
-        my $self = ($class->can('SINGLETON')) ? $class->SINGLETON : undef;
-
-        unless($self){
-            $self = bless({}, $class);
-
-            $self->__initialize if($self->can('__initialize'));
-
-        }
-	# if new is called with initialization values (not recommended)
-        #
-        if(@args % 2 == 0){
-
-		my %args = @args;
-
-		foreach my $k (keys(%args)){
-
-                    my $method = '__'.$k;
-
-                    $self->$method($args{$k}) if($self->can($method));
-                    #$self->{$k} = $args{$k} ;
-
-		}
+   
+    my $self = ($class->can('SINGLETON')) ? $class->SINGLETON : undef;
+    
+    if($self){
+		$self->initialize(@args);
 	}
+	else{
+        $self = bless({}, $class);
         
-        $self;
+        $self->__initialize if($self->can('__initialize'));
+
+    }
+
+
+	$self;
+
 }
 
 
+
 sub __createSetterGetter{
 	my ($class, $attribute, $value) = @_;
 
